==> spip_3.2.11.orig.tar.xz: plugins-dist/statistiques/lang/statistiques_cs.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/statistiques?lang_cible=cs
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// B
	'bouton_effacer_statistiques' => 'Delete the statistics', # MODIF

	// I
	'icone_evolution_visites' => 'Vývoj návštěvnosti<br />@visites@ visites', # MODIF
	'icone_repartition_actuelle' => 'Zobrazit aktuální rozdělení',
	'icone_repartition_visites' => 'Rozdělení návštěv',
	'icone_statistiques_visites' => 'Statistiky',
	'info_affichier_visites_articles_plus_visites' => 'Zobrazit návštěvnost <b>nejoblíbenějších článků od počátku:</b>',
	'info_comment_lire_tableau' => 'Vysvětlivky k tabulce',
	'info_forum_statistiques' => 'Statistiky návštěvnosti',
	'info_popularite_2' => 'oblíbenost webu:',
	'info_popularite_3' => 'oblívenost: @popularite@; návštěvy: @visites@',
	'info_popularite_5' => 'oblíbenost:',
	'info_visites' => 'návštěvy:',
	'info_visites_plus_populaires' => 'Zobrazit návštevnost <b>nejčtenějších</b> a <b>nejnovějších článků:</b>',
	'info_zoom' => 'zvětšit/zmenšit',
	'item_gerer_statistiques' => 'Správa statistik', # MODIF

	// O
	'onglet_origine_visites' => 'Původ návštěv',
	'onglet_repartition_debut' => 'od počátku',
	'onglet_repartition_lang' => 'Rozdělení podle jazyků',

	// R
	'resume' => 'Resume', # MODIF

	// T
	'texte_comment_lire_tableau' => 'Pořadí článku v žebříčku, oblíbenosti je uvedeno na okraji. Oblíbenost článku (odhad každodenního počtu návštěvníků za předpokladu, že počet návštěv bude pokračovat dosavadním tempem) a počet celkových návštěv za celou dobu zveřejnění jsou uvedeny v místní nabídce, která se zobrazí při umístění myši nad názvem článku.',
	'texte_signification' => 'Tmavě jsou označeny kumulované údaje (celkem v rámci podsekcí), světle je uveden počet návštěv v jednotlivých sekcích.',
	'titre_evolution_visite' => 'Vývoj návštěvnosti',
	'titre_liens_entrants' => 'Příchozí odkazy',
	'titre_page_statistiques' => 'Statistiky podle sekcí',
	'titre_page_statistiques_visites' => 'Statistiky návštěvnosti'
);

==> spip_4.4.7+dfsg.orig.tar.xz: plugins-dist/statistiques/lang/statistiques_cs.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/statistiques?lang_cible=cs
// ** ne pas modifier le fichier **

return [

	// B
	'bouton_effacer_statistiques' => 'Delete the statistics', # MODIF

	// I
	'icone_evolution_visites' => 'Vývoj návštěvnosti<br />@visites@ visites', # MODIF
	'icone_repartition_actuelle' => 'Zobrazit aktuální rozdělení',
	'icone_repartition_visites' => 'Rozdělení návštěv',
	'icone_statistiques_visites' => 'Statistiky',
	'info_affichier_visites_articles_plus_visites' => 'Zobrazit návštěvnost <b>nejoblíbenějších článků od počátku:</b>',
	'info_comment_lire_tableau' => 'Vysvětlivky k tabulce',
	'info_forum_statistiques' => 'Statistiky návštěvnosti',
	'info_popularite_2' => 'oblíbenost webu:',
	'info_popularite_3' => 'oblívenost: @popularite@; návštěvy: @visites@',
	'info_popularite_5' => 'oblíbenost:',
	'info_visites' => 'návštěvy:',
	'info_visites_plus_populaires' => 'Zobrazit návštevnost <b>nejčtenějších</b> a <b>nejnovějších článků:</b>',
	'info_zoom' => 'zvětšit/zmenšit',
	'item_gerer_statistiques' => 'Správa statistik', # MODIF

	// O
	'onglet_origine_visites' => 'Původ návštěv',
	'onglet_repartition_debut' => 'od počátku',
	'onglet_repartition_lang' => 'Rozdělení podle jazyků',

	// R
	'resume' => 'Resume', # MODIF

	// T
	'texte_comment_lire_tableau' => 'Pořadí článku v žebříčku, oblíbenosti je uvedeno na okraji. Oblíbenost článku (odhad každodenního počtu návštěvníků za předpokladu, že počet návštěv bude pokračovat dosavadním tempem) a počet celkových návštěv za celou dobu zveřejnění jsou uvedeny v místní nabídce, která se zobrazí při umístění myši nad názvem článku.',
	'texte_signification' => 'Tmavě jsou označeny kumulované údaje (celkem v rámci podsekcí), světle je uveden počet návštěv v jednotlivých sekcích.',
	'titre_evolution_visite' => 'Vývoj návštěvnosti',
	'titre_liens_entrants' => 'Příchozí odkazy',
	'titre_page_statistiques' => 'Statistiky podle sekcí',
	'titre_page_statistiques_visites' => 'Statistiky návštěvnosti',
];
